@@ -8,7 +8,7 @@
 		<p><a href="https://github.com/leongersen/noUiSlider/issues/733">Issue #733</a> asks about clicking pips to move the slider to their value. All <code>.noUi-value</code> elements have a <code>data-value</code> attribute to facilitate this.</code></code></p>
 
 		<div class="example">
-			<div class="slider" id="slider-pips"></div>
+			<div class="slider" id="slider-click-pips"></div>
 
 			<?php run('click-pips-setup'); ?>
 			<?php run('click-pips'); ?>
