@@ -8,7 +8,12 @@ function filterPips(value, type) {
 var pipsSteps = document.getElementById('pips-steps');
 
 noUiSlider.create(pipsSteps, {
-    range: range_all_sliders,
+    range: {
+        'min': [     0 ],
+        '10%': [   500,  500 ],
+        '50%': [  4000, 1000 ],
+        'max': [ 10000 ]
+    },
     start: 0,
     pips: {
         mode: 'steps',
