@@ -1,7 +1,12 @@
 var pipsValuesStepped = document.getElementById('pips-values-stepped');
 
 noUiSlider.create(pipsValuesStepped, {
-    range: range_all_sliders,
+    range: {
+        'min': [     0 ],
+        '10%': [   500,  500 ],
+        '50%': [  4000, 1000 ],
+        'max': [ 10000 ]
+    },
     start: 0,
     pips: {
         mode: 'values',
